@@ -33,9 +33,9 @@ test_that("matsindf_apply works as expected for single matrices", {
 test_that("matsindf_apply works as expected for lists of single values", {
   expect_equal(example_fun(a = list(2, 2), b = list(2, 2)), list(c = list(4, 4), d = list(0, 0)))
   expect_equivalent(matsindf_apply(FUN = example_fun, a = list(2, 2, 2), b = list(2, 2, 2)),
-                    data.frame(c = c(4, 4, 4), d = c(0, 0, 0)))
+                    data.frame(c = c(4, 4, 4), d = c(0, 0, 0), stringsAsFactors = FALSE))
   expect_equivalent(matsindf_apply(FUN = example_fun, a = list(2, 2), b = list(1, 2)),
-                    data.frame(c = c(3, 4), d = c(1, 0)))
+                    data.frame(c = c(3, 4), d = c(1, 0), stringsAsFactors = FALSE))
 })
 
 test_that("matsindf_apply works as expected for lists of matrices", {
@@ -45,7 +45,7 @@ test_that("matsindf_apply works as expected for lists of matrices", {
   d <- a - b
   a <- list(a, a)
   b <- list(b, b)
-  DF_expected <- data.frame(c = I(list(c, c)), d = I(list(d, d)))
+  DF_expected <- data.frame(c = I(list(c, c)), d = I(list(d, d)), stringsAsFactors = FALSE)
   # Because DF_expected$c and DF_expected$d are created with I(list()), their class is "AsIs".
   # Need to set the class of DF_expected$c and DF_expected$d to NULL to get a match.
   attr(DF_expected$c, which = "class") <- NULL
@@ -54,9 +54,9 @@ test_that("matsindf_apply works as expected for lists of matrices", {
 })
 
 test_that("matsindf_apply works as expected using .DF with single numbers", {
-  DF <- data.frame(a = c(4, 4, 5), b = c(4, 4, 4))
+  DF <- data.frame(a = c(4, 4, 5), b = c(4, 4, 4), stringsAsFactors = FALSE)
   expect_equal(matsindf_apply(DF, FUN = example_fun, a = "a", b = "b"),
-               data.frame(a = c(4, 4, 5), b = c(4, 4, 4), c = c(8, 8, 9), d = c(0, 0, 1)))
+               data.frame(a = c(4, 4, 5), b = c(4, 4, 4), c = c(8, 8, 9), d = c(0, 0, 1), stringsAsFactors = FALSE))
 })
 
 test_that("matsindf_apply works as expected using .DF with matrices", {
@@ -64,9 +64,9 @@ test_that("matsindf_apply works as expected using .DF with matrices", {
   b <- a
   c <- a + b
   d <- a - b
-  DF <- data.frame(a = I(list(a, a)), b = I(list(b,b)))
+  DF <- data.frame(a = I(list(a, a)), b = I(list(b,b)), stringsAsFactors = FALSE)
   result <- matsindf_apply(DF, FUN = example_fun, a = "a", b = "b")
-  expected <- dplyr::bind_cols(DF, data.frame(c = I(list(c, c)), d = I(list(d, d))))
+  expected <- dplyr::bind_cols(DF, data.frame(c = I(list(c, c)), d = I(list(d, d)), stringsAsFactors = FALSE))
   expect_equivalent(result, expected)
   # Try with piped .DF argument
   result <- DF %>% matsindf_apply(FUN = example_fun, a = "a", b = "b")
@@ -109,10 +109,10 @@ test_that("matsindf_apply works with a NULL argument", {
   b <- a
   c <- a + b
   d <- a - b
-  DF <- data.frame(a = I(list(a, a)), b = I(list(b,b)))
+  DF <- data.frame(a = I(list(a, a)), b = I(list(b,b)), stringsAsFactors = FALSE)
   # Here is where the NULL is given as an argument to matsindp_apply.
   result <- matsindf_apply(DF, FUN = example_fun, a = "a", b = "b", z = NULL)
-  expected <- dplyr::bind_cols(DF, data.frame(c = I(list(c, c)), d = I(list(d, d))))
+  expected <- dplyr::bind_cols(DF, data.frame(c = I(list(c, c)), d = I(list(d, d)), stringsAsFactors = FALSE))
   expect_equivalent(result, expected)
   # Try with piped .DF argument
   result <- DF %>% matsindf_apply(FUN = example_fun, a = "a", b = "b", z = NULL)
@@ -142,7 +142,7 @@ test_that("matsindf_apply works when .DF supplies some or all argument names", {
 })
 
 test_that("matsindf_apply works for single numbers in data frame columns", {
-  DF <- data.frame(a = c(4, 4, 5), b = c(4, 4, 4))
+  DF <- data.frame(a = c(4, 4, 5), b = c(4, 4, 4), stringsAsFactors = FALSE)
   expected <- DF
   expected$c <- c(8, 8, 9)
   expected$d <- c(0, 0, 1)
